You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@libcloud.apache.org by to...@apache.org on 2021/11/07 18:24:37 UTC

[libcloud] 02/06: Prefix non-standard keyword args with ex

This is an automated email from the ASF dual-hosted git repository.

tomaz pushed a commit to branch trunk
in repository https://gitbox.apache.org/repos/asf/libcloud.git

commit dc61abd06fc6757acad1101cecb45297fb03020c
Author: Dimitris Galanis <di...@gmail.com>
AuthorDate: Sun Nov 7 18:04:12 2021 +0200

    Prefix non-standard keyword args with ex
---
 libcloud/compute/drivers/vultr.py | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/libcloud/compute/drivers/vultr.py b/libcloud/compute/drivers/vultr.py
index 31c9062..2d189d0 100644
--- a/libcloud/compute/drivers/vultr.py
+++ b/libcloud/compute/drivers/vultr.py
@@ -1372,7 +1372,7 @@ class VultrNodeDriverV2(VultrNodeDriver):
                                        method='POST')
         return self._to_volume(resp.object['block'])
 
-    def attach_volume(self, node, volume, live=True):
+    def attach_volume(self, node, volume, ex_live=True):
         """Attaches volume to node.
 
         :param node: Node to attach volume to.
@@ -1381,15 +1381,15 @@ class VultrNodeDriverV2(VultrNodeDriver):
         :param volume: Volume to attach.
         :type volume: :class:`StorageVolume`
 
         :param live: Attach the volume without restarting the node.
         :type live: ``bool``
 
         :rytpe: ``bool``
         """
 
         data = {
             'instance_id': node.id,
-            'live': live,
+            'live': ex_live,
         }
         resp = self.connection.request('/v2/blocks/%s/attach' % volume.id,
                                        data=json.dumps(data),
@@ -1397,19 +1397,19 @@ class VultrNodeDriverV2(VultrNodeDriver):
 
         return resp.success()
 
-    def detach_volume(self, volume, live=True):
+    def detach_volume(self, volume, ex_live=True):
         """Detaches a volume from a node.
 
         :param volume: Volume to be detached
         :type volume: :class:`StorageVolume`
 
         :param live: Detach the volume without restarting the node.
         :type live: ``bool``
 
         :rtype: ``bool``
         """
         data = {
-            'live': live
+            'live': ex_live
         }
 
         resp = self.connection.request('/v2/blocks/%s/detach' % volume.id,
@@ -1381,15 +1381,15 @@ class VultrNodeDriverV2(VultrNodeDriver):
         :type volume: :class:`StorageVolume`
 
-        :param live: Attach the volume without restarting the node.
-        :type live: ``bool``
+        :param ex_live: Attach the volume without restarting the node.
+        :type ex_live: ``bool``
 
         :rytpe: ``bool``
@@ -1397,19 +1397,19 @@ class VultrNodeDriverV2(VultrNodeDriver):
         :type volume: :class:`StorageVolume`
 
-        :param live: Detach the volume without restarting the node.
-        :type live: ``bool``
+        :param ex_live: Detach the volume without restarting the node.
+        :type ex_live: ``bool``
 
         :rtype: ``bool``